'use strict';

exports.__esModule = true;

var _promises = require('./promises');

var _redux = require('redux');

var Timer = function Timer(delay) {
  return ITimer(timerState(delay), {});
};

var ITimer = function ITimer(state, self) {
  return Object.assign(self, {
    start: start(state, self),
    promise: function promise() {
      return state.promise;
    }
  });
};

var timerState = function timerState(delay) {
  return {
    promise: null,
    resolve: null,
    reject: null,
    timier: null,
    delay: delay
  };
};

var start = function start(state, self) {
  return (0, _redux.compose)(function () {
    return self;
  }, startTimer(state), ensureTimerPromise(state), resetTimer(state), setCallback(state));
};

var setCallback = function setCallback(state) {
  return function (cb) {
    state.callback = (0, _promises.ensureAsync)(cb);
  };
};

var resetTimer = function resetTimer(state) {
  return function () {
    if (state.timer) clearTimeout(state.timer);
    state.timer = null;
  };
};

var ensureTimerPromise = function ensureTimerPromise(state) {
  return function () {
    state.promise = state.promise || new Promise(assignResolveReject(state));
  };
};

var assignResolveReject = function assignResolveReject(state) {
  return function (_resolve, _reject) {
    state.resolve = _resolve;
    state.reject = _reject;
  };
};

var startTimer = function startTimer(state) {
  return function () {
    var delay = state.delay,
        resolve = state.resolve,
        reject = state.reject,
        callback = state.callback;


    state.timer = setTimeout(function () {
      return callback().finally(reset(state)).then(resolve, reject);
    }, delay);
  };
};

var reset = function reset(state) {
  return function () {
    state.promise = null;
    state.timer = null;
  };
};

exports.default = Timer;